==> vue-top-box-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/top-box/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import Button from "@dft-vue-2-opentiny/vue-button";
import { iconClose, iconSuccess, iconError, iconHelp, iconWarning, iconInfo } from "@dft-vue-2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconHelp: iconHelp(),
    IconWarning: iconWarning(),
    IconInfo: iconInfo()
  },
  props: [].concat(props, ["emitter"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-top-box-fade"
    },
    on: {
      "after-leave": _vm.handleAfterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    class: ["tiny-top-box", _vm.state.type && !_vm.state.iconClass ? "tiny-top-box--" + _vm.state.type : "", _vm.state.center ? "is-center" : "", _vm.state.showClose ? "is-closable" : "", _vm.state.customClass],
    style: _vm.state.positionStyle,
    attrs: {
      "role": "alert"
    },
    on: {
      "mouseenter": _vm.clearTimer,
      "mouseleave": _vm.startTimer
    }
  }, [_vm.state.iconClass ? _c(_vm.state.iconClass, {
    tag: "component",
    staticClass: "tiny-svg-size"
  }) : _c(_vm.state.typeClass, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-top-box__icon"
  }), _vm._t("default", [!_vm.state.dangerouslyUseHTMLString ? _c("p", {
    staticClass: "tiny-top-box__content"
  }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]) : _c("p", {
    staticClass: "tiny-top-box__content",
    domProps: {
      "innerHTML": _vm._s(_vm.state.message)
    }
  })]), _vm.state.buttons && _vm.state.buttons.length ? _c("div", {
    staticClass: "tiny-top-box__toolbar"
  }, _vm._l(_vm.state.buttons, function(item, key) {
    return _c("tiny-button", {
      key,
      attrs: {
        "type": item.type || ""
      },
      on: {
        "click": item.onClick
      }
    }, [_vm._v(_vm._s(item.text))]);
  }), 1) : _vm._e(), _vm.state.showClose ? _c("icon-close", {
    staticClass: "tiny-svg-size tiny-top-box__closeBtn",
    on: {
      "click": _vm.close
    }
  }) : _vm._e()], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-top-box-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/top-box/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Button from '@opentinyvue/vue-button';
import { iconClose, iconSuccess, iconError, iconHelp, iconWarning, iconInfo } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconHelp: iconHelp(),
    IconWarning: iconWarning(),
    IconInfo: iconInfo()
  },
  props: [].concat(props, ["emitter"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-top-box-fade"
    },
    on: {
      "after-leave": _vm.handleAfterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    class: ["tiny-top-box", _vm.state.type && !_vm.state.iconClass ? "tiny-top-box--" + _vm.state.type : "", _vm.state.center ? "is-center" : "", _vm.state.showClose ? "is-closable" : "", _vm.state.customClass],
    style: _vm.state.positionStyle,
    attrs: {
      "role": "alert"
    },
    on: {
      "mouseenter": _vm.clearTimer,
      "mouseleave": _vm.startTimer
    }
  }, [_vm.state.iconClass ? _c(_vm.state.iconClass, {
    tag: "component",
    staticClass: "tiny-svg-size"
  }) : _c(_vm.state.typeClass, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-top-box__icon"
  }), _vm._t("default", function() {
    return [!_vm.state.dangerouslyUseHTMLString ? _c("p", {
      staticClass: "tiny-top-box__content"
    }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]) : _c("p", {
      staticClass: "tiny-top-box__content",
      domProps: {
        "innerHTML": _vm._s(_vm.state.message)
      }
    })];
  }), _vm.state.buttons && _vm.state.buttons.length ? _c("div", {
    staticClass: "tiny-top-box__toolbar"
  }, _vm._l(_vm.state.buttons, function(item, key) {
    return _c("tiny-button", {
      key,
      attrs: {
        "type": item.type || ""
      },
      on: {
        "click": item.onClick
      }
    }, [_vm._v(_vm._s(item.text))]);
  }), 1) : _vm._e(), _vm.state.showClose ? _c("icon-close", {
    staticClass: "tiny-svg-size tiny-top-box__closeBtn",
    on: {
      "click": _vm.close
    }
  }) : _vm._e()], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
